@@ -9,6 +9,7 @@
 #' @export pick
 #' @param file Either a path to a file, a connection, or literal data (either a single string or a raw vector). The default is NULL, which pops up an interactive GUI file choose dialogue box for users unless an explicit path/to/filename is given.
 #' Each corresponding function depending upon a file extension will be automatically matched and applied once you pick up your file using either the GUI-file-chooser dialog box or explicit path/to/filename.
+#' @param mode Character value for session locale and encoding; available values are: "ko1" for "CP949"; "ko2" for "UTF-8" while both change R locale into Korean (default is the current locale and encoding of your R session).
 #' @param ... Any additional arguments available for each file type and extension:
 #' \link[readr]{read_csv} for CSV (Comma-Separated Values) files; \link[readr]{read_csv2} for CSV2 (Semicolon-Separated Values) files; 
 #' \link[readr]{read_tsv} for 'TSV' (Tab-Separated Values) files; \link[readr]{read_file} for 'txt' (plain text) files; 
@@ -27,7 +28,8 @@
 #' ## Scenario 1: Picking up a file using interactive GUI dialog box:
 #' if(interactive()) {
 #'   library(ezpickr)
-#'   data <- pick()
+#' ## Use either `pick(mode="ko1")` or `pick(mode="ko2")` for Korean R users.
+#'   data <- pick() 
 #' }
 #' 
 #' ## Scenario 2: Picking up a file using an explicit file name ("test.sav" in the example below;
@@ -36,6 +38,7 @@
 #' ## *.html, webpage URL, *doc, *.docx, *.pdf, *.rtf, *.json, *.Rda, *.Rdata, and more):
 #' library(ezpickr)
 #' test <- system.file("extdata", "airquality.sav", package = "ezpickr")
+#' ## Use either `pick(test, mode="ko1")` or `pick(test, mode="ko2")` for Korean R users.
 #' data <- pick(test)
 #' 
 #' # Now you can use the imported file as a tibble.
@@ -45,7 +48,17 @@
 #' @author Soyoung Choi, \email{sxc940@psu.edu}
 
 pick <-
-function(file = NULL, ...) {   # Function starts:
+function(file = NULL, mode = NULL, ...) {   # Function starts:
+
+	if(!is.null(mode)) {
+		if(mode == "ko1") {
+			Sys.setlocale("LC_ALL", "Korean")
+			options(encoding="CP949")
+		} else if(mode == "ko2") {
+			Sys.setlocale("LC_ALL", "Korean")
+			options(encoding="UTF-8")
+		}
+	}
 
 	if (is.null(file)) {
 		fullFile <- file.choose()
